﻿import datetime
from encodings import utf_8
import es
import langlib
import math
import playerlib
import popuplib
import time

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2010/language/"

addon = es.import_addon("soccer_mod_2010/match/stats")

common = langlib.Strings(lang_dir + "popup_common.ini")
text = langlib.Strings(lang_dir + "match/popup_stats_ranking.ini")
messages = langlib.Strings(lang_dir + "match/messages_match_stats_ranking.ini")
messages_common = langlib.Strings(lang_dir + "messages_common.ini")

# ******************** Load ********************
def load():
	es.keygroupcreate("soccer_mod_time")

	create_popup()

# ******************** Events ********************
def player_activate(event_var):
	if es.ServerVar("soccer_mod_allowed") == 1:
		steamid = event_var["es_steamid"]
		if steamid != "BOT":
			if es.exists("key", "soccer_mod_time", steamid) == 0:
				es.keycreate("soccer_mod_time", steamid)

			es.keysetvalue("soccer_mod_time", steamid, "time", int(time.time()))

def player_disconnect(event_var):
	if es.ServerVar("soccer_mod_allowed") == 1:
		steamid = event_var["es_steamid"]
		if steamid != "BOT":
			if es.exists("key", "soccer_mod_time", steamid) == 1:
				seconds = int(time.time()) - int(es.keygetvalue("soccer_mod_time", steamid, "time"))
				addon.execute_query("UPDATE players SET time = (time + %s) WHERE steamid = '%s'" % (seconds, steamid))

				es.keydelete("soccer_mod_time", steamid)

# ******************** Create popup ********************
def create_popup():
	popup = popuplib.create("sm_popup_stats_ranking")

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")

	values = ["rank", "goals", "assists", "own_goals", "hits", "passes", "interceptions", "personal"]
	for i in range(0, 8):
		popup.addline("->%s. %s" % (i + 1, text(values[i])))

	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	for i in range(1, 8):
		popup.select(i, create_ranking)

	popup.select(8, all_time_personal)
	popup.submenu(9, "sm_popup_stats")

# ******************** Commands ********************
def cmd_stats_clear():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	if es.ServerVar("soccer_mod_allowed") == 1:
		addon.execute_query("UPDATE players SET goals = 0, assists = 0, own_goals = 0, hits = 0, passes = 0, interceptions = 0, losses = 0, rank = 0, time = 0 WHERE steamid = '%s'" % (player.steamid))
		es.tell(userid, "#green", messages("clear", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages_common("not_allowed", tokens, player.get("lang")))

# ******************** Popup choice ********************
def create_ranking(userid, choice, popupid):
	if choice == 1:
		type = "rank"
	elif choice == 2:
		type = "goals"
	elif choice == 3:
		type = "assists"
	elif choice == 4:
		type = "own_goals"
	elif choice == 5:
		type = "hits"
	elif choice == 6:
		type = "passes"
	elif choice == 7:
		type = "interceptions"

	es.set("target", 0)

	name = "sm_popup_%s" % (userid)
	query_count = "SELECT steamid FROM players WHERE %s > 0" % (type)
	query = "SELECT name, steamid, %s FROM players WHERE %s > 0 ORDER BY %s desc, name asc" % (type, type, type)

	create_popup_menu(name, "SOCCER MOD %s %s" % (text(type), text("ranking")), query_count, query, 0, 1, 0, type)

	popuplib.send(name, userid)

def all_time_personal(userid, choice, popupid):
	create_popup_player(userid, es.getplayersteamid(userid), 1)

# ******************** Easymenu choice ********************
def rank_choice(userid, choice, popupid):
	rankings_choice(userid, "rank", choice)

def goals_choice(userid, choice, popupid):
	rankings_choice(userid, "goals", choice)

def assists_choice(userid, choice, popupid):
	rankings_choice(userid, "assists", choice)

def own_goals_choice(userid, choice, popupid):
	rankings_choice(userid, "own_goals", choice)

def hits_choice(userid, choice, popupid):
	rankings_choice(userid, "hits", choice)

def passes_choice(userid, choice, popupid):
	rankings_choice(userid, "passes", choice)

def interceptions_choice(userid, choice, popupid):
	rankings_choice(userid, "interceptions", choice)

# ******************** Functions ********************
def create_popup_menu(name, title, query_count, query, menu, value, result, block):
	if popuplib.exists(name):
		popuplib.delete(name)

	popup = popuplib.create(name)
	popup.addline(title)
	popup.addline(" ")

	cursor = addon.execute_query(query_count, 1)

	number = 0
	for row in cursor:
		number += 1

	results = float(number)
	pages = int(math.ceil(results / 7))
	page = (result / 7) + 1

	temp_results = int(results)
	temp_result = result + 1
	temp_result2 = result + 7
	if temp_result2 > temp_results:
		temp_result2 = temp_results

	query_limit = "%s LIMIT %s, 7" % (query, result)
	addon.execute_query(query_limit)

	number = 0
	position = temp_result
	for row in cursor:
		number += 1
		popup.addline("->%s. %s %s" % (position, row[2], row[menu]))
		popup.menuvalue("target", number, row[value])
		position += 1

	popup.addline(" ")

	tokens = {}
	tokens["page"] = page
	tokens["pages"] = pages
	popup.addline(text("pages", tokens))

	tokens["start"] = temp_result
	tokens["end"] = temp_result2
	tokens["results"] = temp_results
	popup.addline(text("results", tokens))

	if results > 7:
		popup.addline(" ")

	back = result - 7
	if back < 0:
		back = 0
	else:
		popup.addline("->8. %s" % (common("previous")))

	popup.menuvalue("result", 8, back)

	next = result + 7
	if next >= results:
		next = result
	else:
		popup.addline("->9. %s" % (common("next")))

	popup.menuvalue("result", 9, next)

	popup.addline(" ")
	popup.addline("0. %s" % (common("cancel")))

	if block == "rank":
		popup.menuselect = rank_choice
	elif block == "goals":
		popup.menuselect = goals_choice
	elif block == "assists":
		popup.menuselect = assists_choice
	elif block == "own_goals":
		popup.menuselect = own_goals_choice
	elif block == "hits":
		popup.menuselect = hits_choice
	elif block == "passes":
		popup.menuselect = passes_choice
	elif block == "interceptions":
		popup.menuselect = interceptions_choice

def rankings_choice(userid, type, choice):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	query_count = "SELECT steamid FROM players WHERE %s > 0" % (type)
	query = "SELECT name, steamid, %s FROM players WHERE %s > 0 ORDER BY %s desc, name asc" % (type, type, type)

	target = es.ServerVar("target")
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8 or choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		title = "SOCCER MOD %s %s" % (text(type), text("ranking"))
		create_popup_menu(name, title, query_count, query, 0, 1, result, type)
		popuplib.send(name, userid)
	elif choice == 10:
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		result = es.ServerVar("result")
		es.set("target", 0)
		title = "SOCCER MOD %s %s" % (text(type), text("ranking"))
		create_popup_menu(name, title, query_count, query, 0, 1, result, type)
		popuplib.send(name, userid)

def create_popup_player(userid, steamid, personal = 0):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popup = popuplib.create(name)

	if personal == 0:
		popup.addline("SOCCER MOD %s" % (text("title_all_time_player")))
	else:
		popup.addline("SOCCER MOD %s" % (text("title_all_time_personal")))

	popup.addline(" ")

	cursor = addon.execute_query("SELECT name, goals, assists, own_goals, hits, passes, interceptions, rank, connected, time FROM players WHERE steamid = '%s'" % (steamid), 1)
	for row in cursor:
		if personal == 0:
			popup.addline("%s:" % (row[0]))
			popup.addline(" ")

			try:
				play_time = int(time.time()) - int(row[8])

				day = 86400

				days = int(math.floor(play_time / day))
				play_time -= days * day

				hours = int(math.floor(play_time / 3600))
				play_time -= hours * 3600
				if hours < 10:
					hours = "0%s" % (hours)

				minutes = int(math.floor(play_time / 60))
				play_time -= minutes * 60
				if minutes < 10:
					minutes = "0%s" % (minutes)

				if play_time < 10:
					seconds = "0%s" % (play_time)
				else:
					seconds = play_time

				if days < 1:
					popup.addline("%s: %s:%s:%s ago" % (text("last_connected"), hours, minutes, seconds))
				elif days == 1:
					popup.addline("%s: %s day %s:%s:%s ago" % (text("last_connected"), days, hours, minutes, seconds))
				else:
					popup.addline("%s: %s days %s:%s:%s ago" % (text("last_connected"), days, hours, minutes, seconds))
			except ValueError:
				popup.addline("%s: %s" % (text("last_connected"), row[8]))

		if es.exists("key", "soccer_mod_time", steamid) == 1:
			play_time = row[9] + (int(time.time()) - int(es.keygetvalue("soccer_mod_time", steamid, "time")))
		else:
			play_time = row[9]

		day = 86400

		days = int(math.floor(play_time / day))
		play_time -= days * day

		hours = int(math.floor(play_time / 3600))
		play_time -= hours * 3600
		if hours < 10:
			hours = "0%s" % (hours)

		minutes = int(math.floor(play_time / 60))
		play_time -= minutes * 60
		if minutes < 10:
			minutes = "0%s" % (minutes)

		if play_time < 10:
			seconds = "0%s" % (play_time)
		else:
			seconds = play_time

		if days < 1:
			popup.addline("%s: %s:%s:%s" % (text("time_played"), hours, minutes, seconds))
		elif days == 1:
			popup.addline("%s: %s day %s:%s:%s" % (text("time_played"), days, hours, minutes, seconds))
		else:
			popup.addline("%s: %s days %s:%s:%s" % (text("time_played"), days, hours, minutes, seconds))

		if row[7] > 0:
			info = get_rank("rank", steamid)
			line = "%s: %s (%s / %s)" % (text("ranking_points"), row[7], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("ranking_points"))
		popup.addline(line)

		values = ["goals", "assists", "own_goals", "hits", "passes", "interceptions"]
		for i in range(0, len(values)):
			if row[i + 1] > 0:
				info = get_rank(values[i], steamid)
				line = "%s: %s (%s / %s)" % (text(values[i]), row[i + 1], info[0], info[1])
			else:
				line = "%s: no rank yet" % (text(values[i]))
			popup.addline(line)

	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (common("close")))

	for i in range(1, 9):
		popup.submenu(i, name)

	popup.submenu(9, "sm_popup_stats_ranking")

	popuplib.send(name, userid)

def get_rank(stat, steamid):
	cursor = addon.execute_query("SELECT steamid FROM players WHERE %s > 0 ORDER BY %s desc, name asc" % (stat, stat), 1)
	number = 0
	rank = 0
	stop = 0
	for result in cursor:
		number += 1
		if stop == 0:
			rank += 1
			note = result[0]
			check = note.encode("utf-8")
			if check == steamid:
				stop = 1
	info = [rank, number]
	return info

# ******************** Unload ********************
def unload():
	es.keygroupdelete("soccer_mod_time")

	popuplib.delete("sm_popup_stats_ranking")